# django-stw

[![Build Status](https://travis-ci.org/saschwarz/django-stw.svg?branch=https)](https://travis-ci.org/saschwarz/django-stw)

Django application for inserting [Shrink The Web](https://www.shrinktheweb.com/) images into templates.

Contains a templatetag providing a thin wrapper around the STW api:
- [https://shrinktheweb.com/uploads/STW_API_Documentation.pdf](https://shrinktheweb.com/uploads/STW_API_Documentation.pdf)
- [https://shrinktheweb.com/uploads/PRO_Feature_Documentation.pdf](https://shrinktheweb.com/uploads/PRO_Feature_Documentation.pdf)

This application is tested using Django 1.9, 1.10 and Python 2.7, 3.5.

Includes an example view/template for demo purposes. See INSTALL.txt for details.

You can also see the [running demo](http://www.googility.com/django-stw/)
